EpochChange

Struct EpochChange 

pub struct EpochChange { /* private fields */ }
A sequence of epochs, driven by who is trusted.

Implementations

Source

impl EpochChange

pub fn new( me: NodeId, peers: impl IntoIterator<Item = NodeId>, timing: Timing, ) -> Self

Epoch-change among peers, over a leader detector with the given heartbeat and timeout and a best-effort broadcast whose links retransmit every retransmit.

pub fn last_timestamp(&self) -> u64

The epoch this process has most recently started, if any.

pub fn trusted(&self) -> NodeId

Who this process currently trusts.