pub struct EpochChange { /* private fields */ }Expand description
A sequence of epochs, driven by who is trusted.
Implementations
Sourceimpl EpochChange
impl EpochChange
Sourcepub fn new(
me: NodeId,
peers: impl IntoIterator<Item = NodeId>,
timing: Timing,
) -> Self
pub fn new( me: NodeId, peers: impl IntoIterator<Item = NodeId>, timing: Timing, ) -> Self
Epoch-change among peers, over a leader detector with the given heartbeat and timeout and
a best-effort broadcast whose links retransmit every retransmit.
Sourcepub fn last_timestamp(&self) -> u64
pub fn last_timestamp(&self) -> u64
The epoch this process has most recently started, if any.